@@ -1,3 +1,15 @@
+# Copyright 2019 Justin Cally
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# https://www.apache.org/licenses/LICENSE-2.0.txt
+#
+# Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and limitations under the License.
+
 #' List Available WFS Layers
 #' @description Lists layers available from the WFS geoserver. This is similar to sending the 
 #' WFS request of `getFeatureTypes`. `listLayers()` returns a data.frame with the 'Name' and title of the
@@ -23,6 +35,9 @@ listLayers <- function(...) {
   request <- httr::build_url(url)
   response <- httr::GET(request)
   
+  # stop if broken
+  httr::stop_for_status(response)
+  
   parsed <- httr::content(response, encoding = "UTF-8") %>% xml2::xml_child(4)
   attr_list <- xml2::as_list(parsed)
   
